@@ -21,7 +21,9 @@ from wsme import Unset
 # other controllers
 from nodes import NodesController
 from virtualips import VipsController
+from health_monitor import HealthMonitorController
 from logs import LogsController
+
 # models
 from libra.api.model.lbaas import LoadBalancer, Device, Node, db_session
 from libra.api.model.lbaas import loadbalancers_devices, Limits
@@ -228,6 +230,24 @@ class LoadBalancersController(RestController):
             old_lb = None
             # if we don't have an id then we want to create a new lb
             lb = LoadBalancer()
+            lb.tenantid = tenant_id
+            lb.name = body.name
+            if body.protocol and body.protocol.lower() == 'tcp':
+                lb.protocol = 'TCP'
+            else:
+                lb.protocol = 'HTTP'
+
+            if body.port:
+                lb.port = body.port
+            else:
+                if lb.protocol == 'HTTP':
+                    lb.port = 80
+                else:
+                    lb.port = 443
+
+            lb.status = 'BUILD'
+            lb.created = None
+
             if body.virtualIps == Unset:
                 # find free device
                 # lock with "for update" so multiple APIs don't grab the same
@@ -256,57 +276,24 @@ class LoadBalancersController(RestController):
                     session.rollback()
                     raise NotFound('Invalid virtual IP provided')
 
-                if body.protocol == Unset or body.protocol.lower() == 'HTTP':
-                    old_count = session.query(
-                        LoadBalancer
-                    ).join(LoadBalancer.devices).\
-                        filter(LoadBalancer.tenantid == tenant_id).\
-                        filter(Device.id == virtual_id).\
-                        filter(LoadBalancer.protocol == 'HTTP').\
-                        count()
-                    if old_count:
-                        session.rollback()
-                        # Error here, can have only one HTTP
-                        raise ClientSideError(
-                            'Only one HTTP load balancer allowed per device'
-                        )
-                elif body.protocol.lower() == 'TCP':
-                    old_count = session.query(
-                        LoadBalancer
-                    ).join(LoadBalancer.devices).\
-                        filter(LoadBalancer.tenantid == tenant_id).\
-                        filter(Device.id == virtual_id).\
-                        filter(LoadBalancer.protocol == 'TCP').\
-                        count()
-                    if old_count:
-                        session.rollback()
-                        # Error here, can have only one TCP
-                        raise ClientSideError(
-                            'Only one TCP load balancer allowed per device'
-                        )
+                old_count = session.query(
+                    LoadBalancer
+                ).join(LoadBalancer.devices).\
+                    filter(LoadBalancer.tenantid == tenant_id).\
+                    filter(Device.id == virtual_id).\
+                    filter(LoadBalancer.port == lb.port).\
+                    count()
+                if old_count:
+                    session.rollback()
+                    # Error here, can have only one LB per port on a device
+                    raise ClientSideError(
+                        'Only one load balancer per port allowed per device'
+                    )
 
             if device is None:
                 session.rollback()
                 raise RuntimeError('No devices available')
 
-            lb.tenantid = tenant_id
-            lb.name = body.name
-            if body.protocol and body.protocol.lower() == 'tcp':
-                lb.protocol = 'TCP'
-            else:
-                lb.protocol = 'HTTP'
-
-            if body.port:
-                lb.port = body.port
-            else:
-                if lb.protocol == 'HTTP':
-                    lb.port = 80
-                else:
-                    lb.port = 443
-
-            lb.status = 'BUILD'
-            lb.created = None
-
             if body.algorithm:
                 lb.algorithm = body.algorithm.upper()
             else:
@@ -321,18 +308,19 @@ class LoadBalancersController(RestController):
             for node in body.nodes:
                 if node.condition == 'DISABLED':
                     enabled = 0
+                    node_status = 'OFFLINE'
                 else:
                     enabled = 1
+                    node_status = 'ONLINE'
                 out_node = Node(
                     lbid=lb.id, port=node.port, address=node.address,
-                    enabled=enabled, status='ONLINE', weight=1
+                    enabled=enabled, status=node_status, weight=1
                 )
                 session.add(out_node)
 
             # now save the loadbalancer_id to the device and switch its status
             # to online
             device.status = "ONLINE"
-
             session.flush()
 
             return_data = LBResp()
@@ -476,6 +464,8 @@ class LoadBalancersController(RestController):
                 return VipsController(lbid), remainder[1:]
             if remainder[0] == 'logs':
                 return LogsController(lbid), remainder[1:]
+            if remainder[0] == 'healthmonitor':
+                return HealthMonitorController(lbid), remainder[1:]
 
         # Kludgy fix for PUT since WSME doesn't like IDs on the path
         elif lbid:
