@@ -168,11 +168,13 @@ class NodesController(RestController):
             for node in body.nodes:
                 if node.condition == 'DISABLED':
                     enabled = 0
+                    node_status = 'OFFLINE'
                 else:
                     enabled = 1
+                    node_status = 'ONLINE'
                 new_node = Node(
                     lbid=self.lbid, port=node.port, address=node.address,
-                    enabled=enabled, status='ONLINE', weight=1
+                    enabled=enabled, status=node_status, weight=1
                 )
                 session.add(new_node)
                 session.flush()
@@ -184,7 +186,7 @@ class NodesController(RestController):
                     NodeResp(
                         id=new_node.id, port=new_node.port,
                         address=new_node.address, condition=condition,
-                        status='ONLINE'
+                        status=new_node.status
                     )
                 )
             device = session.query(
@@ -225,19 +227,21 @@ class NodesController(RestController):
                 session.rollback()
                 raise NotFound('Node ID is not valid')
 
-            nodecount = session.query(Node).\
-                filter(Node.lbid == self.lbid).\
-                filter(Node.enabled == 1).count()
             if body.condition != Unset:
                 if body.condition == 'DISABLED':
+                    nodecount = session.query(Node).\
+                        filter(Node.lbid == self.lbid).\
+                        filter(Node.enabled == 1).count()
+                    if nodecount <= 1:
+                        session.rollback()
+                        raise ClientSideError(
+                            "Cannot disable the last enabled node"
+                        )
                     node.enabled = 0
+                    node.status = 'OFFLINE'
                 else:
                     node.enabled = 1
-            if nodecount <= 1:
-                session.rollback()
-                raise ClientSideError(
-                    "Cannot disable the last enabled node in a load balancer"
-                )
+                    node.status = 'ONLINE'
 
             lb.status = 'PENDING_UPDATE'
             device = session.query(
