@@ -17,6 +17,7 @@ eventlet.monkey_patch()
 import logging
 from libra.common.json_gearman import JSONGearmanClient
 from libra.api.model.lbaas import LoadBalancer, db_session, Device, Node
+from libra.api.model.lbaas import HealthMonitor
 from libra.api.model.lbaas import loadbalancers_devices
 from sqlalchemy.exc import OperationalError
 from pecan import conf
@@ -70,7 +71,21 @@ class GearmanClientThread(object):
         self.logger = logger
         self.host = host
         self.lbid = lbid
-        self.gearman_client = JSONGearmanClient(conf.gearman.server)
+
+        if all([conf.gearman.ssl_key, conf.gearman.ssl_cert,
+                conf.gearman.ssl_ca]):
+            # Use SSL connections to each Gearman job server.
+            ssl_server_list = []
+            for server in conf.gearman.server:
+                ghost, gport = server.split(':')
+                ssl_server_list.append({'host': ghost,
+                                        'port': int(gport),
+                                        'keyfile': conf.gearman.ssl_key,
+                                        'certfile': conf.gearman.ssl_cert,
+                                        'ca_certs': conf.gearman.ssl_ca})
+            self.gearman_client = JSONGearmanClient(ssl_server_list)
+        else:
+            self.gearman_client = JSONGearmanClient(conf.gearman.server)
 
     def send_delete(self, data):
         with db_session() as session:
@@ -107,8 +122,9 @@ class GearmanClientThread(object):
                         continue
                     condition = 'ENABLED'
                     node_data = {
-                        'port': node.port, 'address': node.address,
-                        'weight': node.weight, 'condition': condition
+                        'id': node.id, 'port': node.port,
+                        'address': node.address, 'weight': node.weight,
+                        'condition': condition
                     }
                     job_data['loadBalancers'][0]['nodes'].append(node_data)
             else:
@@ -138,6 +154,8 @@ class GearmanClientThread(object):
             ))
             session.query(Node).\
                 filter(Node.lbid == lb.id).delete()
+            session.query(HealthMonitor).\
+                filter(HealthMonitor.lbid == lb.id).delete()
             session.commit()
 
     def _set_error(self, device_id, errmsg, session):
@@ -197,32 +215,68 @@ class GearmanClientThread(object):
                 'hpcs_action': 'UPDATE',
                 'loadBalancers': []
             }
+
+            is_degraded = False
             for lb in lbs:
                 lb_data = {
                     'name': lb.name,
                     'protocol': lb.protocol,
                     'algorithm': lb.algorithm,
                     'port': lb.port,
-                    'nodes': []
+                    'nodes': [],
+                    'monitor': {}
                 }
                 for node in lb.nodes:
                     if not node.enabled:
                         continue
                     condition = 'ENABLED'
                     node_data = {
-                        'port': node.port, 'address': node.address,
-                        'weight': node.weight, 'condition': condition
+                        'id': node.id, 'port': node.port,
+                        'address': node.address, 'weight': node.weight,
+                        'condition': condition
                     }
                     lb_data['nodes'].append(node_data)
+                    # Track if we have a DEGRADED LB
+                    if lb.id == self.lbid and node.status == 'ERROR':
+                        is_degraded = True
+
+                # Add a default health monitor if one does not exist
+                monitor = session.query(HealthMonitor).\
+                    filter(HealthMonitor.lbid == lb.id).first()
+
+                if monitor is None:
+                    # Set it to a default configuration
+                    monitor = HealthMonitor(
+                        lbid=lb.id, type="CONNECT", delay=30,
+                        timeout=30, attempts=2, path=None
+                    )
+                    session.add(monitor)
+                    session.flush()
+
+                monitor_data = {
+                    'type': monitor.type,
+                    'delay': monitor.delay,
+                    'timeout': monitor.timeout,
+                    'attempts': monitor.attempts
+                }
+                if monitor.path is not None:
+                    monitor_data['path'] = monitor.path
+
+                lb_data['monitor'] = monitor_data
                 job_data['loadBalancers'].append(lb_data)
+
+            # Update the worker
             status, response = self._send_message(job_data)
             lb = session.query(LoadBalancer).\
                 filter(LoadBalancer.id == self.lbid).\
                 first()
             if not status:
                 self._set_error(data, response, session)
+            elif is_degraded:
+                lb.status = 'DEGRADED'
             else:
                 lb.status = 'ACTIVE'
+
             session.commit()
 
     def _send_message(self, message):
